@@ -17,7 +17,7 @@ from PyQt4 import QtGui, QtCore
 
 from rest_in_peace_gui import *
 
-CURRENTVERSION = "0.1.0i"
+CURRENTVERSION = "0.2.0"
 
 
 #mytimer = timer.Timer()
@@ -181,7 +181,7 @@ class MyForm(QtGui.QMainWindow):
 
 
     def showTips(self):
-        tipsString = "I have pre-populated a few CellIDs for stations in the UK. Choose one of the favorites, enable the  alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Save current CellID'<p><b>NOTE:</b> The current version only associates a single CellID with a destination. So if you are on dual GSM/3G mode, it is possible the alarm may not sound. <em>Please <b>ensure</b> you are on <b>GSM only</b> before falling asleep</em> (<a href='http://github.com/abrisse/AutoDisconnect'>AutoDisconnect</a> does this for me automatically. YMMV)"
+        tipsString = "Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Add CellID'"
         #TODO: update tips
 
 	self.label = QtGui.QLabel(tipsString)
@@ -202,7 +202,7 @@ class MyForm(QtGui.QMainWindow):
 
 
     def showAbout(self):
-        aboutString = "Rest in Peace: v" + CURRENTVERSION + "\nGirish Gopi (rip@gman.me.uk)\nMany thanks to qwerty12, lma, mikec, fatalsaint, Dvortygirl (icon) plus all of t.m.o (& w.m.o)"
+        aboutString = "Rest in Peace: v" + CURRENTVERSION + "\nGirish Gopi (rip@gman.me.uk) - version 0.1\nSerhiy Zahoriya (xintx.ua@gmail.com) - version 0.2\nMany thanks to qwerty12, lma, mikec, fatalsaint, Dvortygirl (icon) plus all of t.m.o (& w.m.o)"
         QtGui.QMessageBox.information(self, "About R.I.P", aboutString)
 
     def closeTips(self):
@@ -274,6 +274,3 @@ if __name__ == '__main__':
     myapp.show()
     sys.exit(app.exec_())
 
-# see 11120...txt
-# unalarm button
-# check current cellid on setting the alarm
